Struct Apb1rstr2
#[repr(transparent)]pub struct Apb1rstr2(pub u32);Expand description
RCC APB1 peripheral reset register 2
Tuple Fields
0: u32Implementations
impl Apb1rstr2
impl Apb1rstr2
pub const fn set_i2c4rst(&mut self, val: bool)
pub const fn set_i2c4rst(&mut self, val: bool)
I2C4 reset Set and cleared by software
pub const fn set_lptim2rst(&mut self, val: bool)
pub const fn set_lptim2rst(&mut self, val: bool)
LPTIM2 reset Set and cleared by software.
pub const fn i2c5rst(&self) -> bool
pub const fn i2c5rst(&self) -> bool
I2C5 reset This bit is set and cleared by software Note: This bit is only available on some devices in the STM32U5 Series. Refer to the device datasheet for availability of its associated peripheral. If not present, consider this bit as reserved and keep it at reset value.
pub const fn set_i2c5rst(&mut self, val: bool)
pub const fn set_i2c5rst(&mut self, val: bool)
I2C5 reset This bit is set and cleared by software Note: This bit is only available on some devices in the STM32U5 Series. Refer to the device datasheet for availability of its associated peripheral. If not present, consider this bit as reserved and keep it at reset value.
pub const fn i2c6rst(&self) -> bool
pub const fn i2c6rst(&self) -> bool
I2C6 reset This bit is set and cleared by software Note: This bit is only available on some devices in the STM32U5 Series. Refer to the device datasheet for availability of its associated peripheral. If not present, consider this bit as reserved and keep it at reset value.
pub const fn set_i2c6rst(&mut self, val: bool)
pub const fn set_i2c6rst(&mut self, val: bool)
I2C6 reset This bit is set and cleared by software Note: This bit is only available on some devices in the STM32U5 Series. Refer to the device datasheet for availability of its associated peripheral. If not present, consider this bit as reserved and keep it at reset value.
pub const fn set_fdcan1rst(&mut self, val: bool)
pub const fn set_fdcan1rst(&mut self, val: bool)
FDCAN1 reset Set and cleared by software.
pub const fn set_ucpd1rst(&mut self, val: bool)
pub const fn set_ucpd1rst(&mut self, val: bool)
UCPD1 reset Set and cleared by software.